@@ -5,8 +5,9 @@
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- * Copyright (c) 2020 Red Hat, Inc.
  ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 import { gql } from 'apollo-server-express';
 
@@ -17,6 +18,15 @@ type Query {
   # Get application resources.
   application(name: String, namespace: String): Application
 
+  # Get basic list of all applications (including Argo)
+  applications(name: String, namespace: String): [BasicApplication]
+
+  # Get ArgoApp Route URL
+  argoAppRouteURL(cluster: String!, namespace: String!, name: String!, apiVersion: String!): String
+
+  # Get Route resource URL
+  routeResourceURL(cluster: String!, namespace: String!, name: String!, apiVersion: String!): String
+
   # Get all channel resources. Optionally, specify name and namespace to filter results.
   channels(name: String, namespace: String): [Channel]
 
@@ -26,33 +36,6 @@ type Query {
   # Get all paths for a Git channel
   gitChannelPaths(gitUrl: String!, branch: String!, path: String, namespace: String, secretRef: String, user: String, accessToken: String): [String]
 
-  # Get a cluster resource.
-  cluster(name: String, namespace: String): [Cluster]
-
-  # List all managed clusters.
-  clusters: [Cluster]
-
-  # List all cluster image sets.
-  clusterImageSets: [ClusterImageSet]
-
-  # Get the ManagedClusterAddons
-  clusterAddons(name: String, namespace: String): [ClusterAddon]
-
-  # BareMetalAssests
-  bareMetalAsset(name: String, namespace: String): [BareMetalAsset]
-  bareMetalAssets(fetchSecrets: Boolean): [BareMetalAsset]
-  bareMetalAssetSubresources(name: String, namespace: String): BareMetalAssetSubresources
-
-  # Get Compliance/Policy info
-  compliances(name: String, namespace: String): [Compliance] @deprecated(reason: "Compliances are deprecated from OCM. Use policies instead.")
-
-  # Security findings
-  occurrences: [Occurrence]
-
-  # List all cloud connections and orchestrations
-  connections: [Connection]
-  connectionDetails(name: String, namespace: String): [ConnectionDetail]
-
   # Get any kubernetes resource from any managed cluster.
   getResource(apiVersion: String, kind: String, name: String, namespace: String, cluster: String, selfLink: String, updateInterval: Int, deleteAfterUse: Boolean): JSON
 
@@ -69,7 +52,10 @@ type Query {
   placementrules (name: String, namespace: String): [PlacementRule]
 
   # Get secrets
-  secrets(namespace: String): [Secret]
+  secrets(label: String, value: String): [Secret]
+
+  # Get ManagedClusterConditionAvailable
+  isManagedClusterConditionAvailable(clusterName: String): Boolean
 
   # Get all subscription resources. Optionally, specify name and namespace to filter results.
   subscriptions(name: String, namespace: String): [Subscription]
@@ -101,8 +87,6 @@ type Query {
 
   # Gets data for the topology diagram.
   topology(filter: TopologyFilter): Topology
-
-  getAutomatedImportStatus(namespace: String, name: String): JSON
 }
 
 # Multicloud Manager Mutations
@@ -151,22 +135,6 @@ type Mutation {
 
   # Delete a ManagedClusterView resource
   deleteManagedClusterView(managedClusterNamespace: String, managedClusterViewName: String): JSON
-
-  # Create remote cluster
-  createCluster(cluster: JSON!) : JSON
-
-  automatedImport(namespace: String, name: String, body: JSON): JSON
-
-  detachCluster(namespace: String!, cluster: String!, destroy: Boolean): JSON
-  updateClusterResource(namespace: String, name: String, body: String): JSON
-
-  # BareMetalAssests
-  createBareMetalAsset(namespace: String, name: String, bmcAddress: String, username: String, password: String, bootMac: String): JSON
-  updateBareMetalAsset(namespace: String, name: String, bmcAddress: String, username: String, password: String, bootMac: String): JSON
-  deleteBareMetalAssets(bmas: [JSON]): JSON
-
-  # DEPRECATED MUTATIONS
-  createCompliance(resources: [JSON]): JSON  @deprecated(reason: "Compliances are deprecated from MCM. Use policies instead.")
 }
 
 # Common fields for all Kubernetes objects
@@ -186,19 +154,6 @@ type Metadata {
   status: String
   uid: String
 }
-
-#fields for all API objects
-interface ConnectionObject {
-  metadata: ConnectionMetadata
-}
-
- #Common fields for all API objects
-type ConnectionMetadata {
-  name: String
-  namespace: String
-  provider: String
-  name_namespace: String
-}
 `;
 
 export const resolver = {
@@ -208,10 +163,4 @@ export const resolver = {
       return null;
     },
   },
-  ConnectionObject: {
-    // eslint-disable-next-line no-underscore-dangle
-    __resolveType() {
-      return null;
-    },
-  },
 };
